# $Id: basicfirst.py,v 1.3 2002/03/08 11:06:38 kjetilja Exp $

import sys
import pycurl

url = 'http://curl.haxx.se/dev/'
contents = ''

def body_callback(buf):
    global contents
    contents = contents + buf
    return len(buf)

print 'Testing', pycurl.version

c = pycurl.init()
c.setopt(pycurl.URL, url)
c.setopt(pycurl.WRITEFUNCTION, body_callback)
c.setopt(pycurl.HTTPHEADER, ["I-am-a-silly-programmer: yes indeed you are",
                             "User-Agent: Python interface for libcURL"])
c.perform()
c.cleanup()

print contents



# $Id: test_stringio.py,v 1.2 2002/03/08 11:07:57 kjetilja Exp $

import sys
import pycurl
try:
    from cStringIO import StringIO
except ImportError:
    from StringIO import StringIO

url = 'http://curl.haxx.se/dev/'

print 'Testing', pycurl.version

body = StringIO()
c = pycurl.init()
c.setopt(pycurl.URL, url)
c.setopt(pycurl.WRITEFUNCTION, body.write)
c.perform()
c.cleanup()

contents = body.getvalue()
print contents



# $Id: test_xmlrpc2.py,v 1.1 2001/08/20 15:07:45 kjetilja Exp $

## Py-XMLRPC module (get it from sourceforge.net)
import xmlrpc

## PycURL module
import pycurl

# Build request, but discard the header
req = xmlrpc.buildRequest('/RPC2', 'examples.getStateName', [5], {}).split('\r\n\r\n')[1]
c = pycurl.init()
c.setopt(pycurl.URL, 'http://betty.userland.com/RPC2')
c.setopt(pycurl.FOLLOWLOCATION, 1)
c.setopt(pycurl.POST, 1)
c.setopt(pycurl.POSTFIELDS, req)
c.perform()
c.cleanup()



# $Id: test_post2.py,v 1.2 2002/04/12 14:00:32 kjetilja Exp $

import pycurl

pf = ['field1=this is a test using httppost & stuff', 'field2=value2']

c = pycurl.init()
c.setopt(pycurl.URL, 'http://pycurl.sourceforge.net/tests/testpostvars.php')
c.setopt(pycurl.POST, 1)
c.setopt(pycurl.HTTPPOST, pf)
c.perform()
c.cleanup()



# $Id: basicfirst2.py,v 1.3 2002/03/08 11:06:38 kjetilja Exp $

import sys
import pycurl


class test:
    def __init__(self):
        self.contents = ''

    def body_callback(self, buf):
        self.contents = self.contents + buf

print 'Testing', pycurl.version

t = test()
c = pycurl.init()
c.setopt(pycurl.URL, 'http://curl.haxx.se/dev/')
c.setopt(pycurl.WRITEFUNCTION, t.body_callback)
c.setopt(pycurl.HTTPHEADER, ["I-am-a-silly-programmer: yes indeed you are",
                             "User-Agent: Python interface for libcURL"])
c.perform()
c.cleanup()

print t.contents



# $Id: test_debug.py,v 1.2 2002/04/15 12:02:59 kjetilja Exp $

import pycurl

def test(t, b):
    print "debug(%d): %s" % (t, b)

c = pycurl.init()
c.setopt(pycurl.URL, 'http://curl.haxx.se/')
c.setopt(pycurl.VERBOSE, 1)
c.setopt(pycurl.DEBUGFUNCTION, test)
c.perform()
c.cleanup()



# $Id: test_getinfo.py,v 1.8 2002/02/21 15:13:38 kjetilja Exp $

## PycURL module
import pycurl

## Callback function invoked when progress information is updated
def progress(download_t, download_d, upload_t, upload_d):
    print 'Total to download %d bytes, have %d bytes so far' % \
          (download_t, download_d)

print 'Starting downloading http://curl.haxx.se/'
print
f = open('body', 'w')
h = open('header', 'w')
c = pycurl.init()
c.setopt(pycurl.URL, 'http://curl.haxx.se')
c.setopt(pycurl.FILE, f)
c.setopt(pycurl.NOPROGRESS, 0)
c.setopt(pycurl.PROGRESSFUNCTION, progress)
c.setopt(pycurl.FOLLOWLOCATION, 1)
c.setopt(pycurl.MAXREDIRS, 5)
c.setopt(pycurl.WRITEHEADER, h)
c.perform()

print
print 'Download speed: %f bytes/second' % c.getinfo(pycurl.SPEED_DOWNLOAD)
print 'Document size: %d bytes' % c.getinfo(pycurl.SIZE_DOWNLOAD)
print 'Effective URL:', c.getinfo(pycurl.EFFECTIVE_URL)
print 'Content-type:', c.getinfo(pycurl.CONTENT_TYPE)
print
print "Header is in file 'header', body is in file 'body'"

c.cleanup()
f.close()
h.close()



# $Id: test_xmlrpc.py,v 1.4 2002/02/26 09:59:30 kjetilja Exp $

## PycURL module
import pycurl

## XML-RPC lib included in python2.2
import xmlrpclib

# Header fields passed in request
xmlrpc_header = [
    "User-Agent: PycURL XML-RPC Test", "Content-Type: text/xml"
    ]

# XML-RPC request template
xmlrpc_template = """
<?xml version='1.0'?><methodCall><methodName>%s</methodName>%s</methodCall>
"""

# Engage
c = pycurl.init()
c.setopt(pycurl.URL, 'http://betty.userland.com/RPC2')
c.setopt(pycurl.POST, 1)
c.setopt(pycurl.HTTPHEADER, xmlrpc_header)
c.setopt(pycurl.POSTFIELDS, xmlrpc_template % ("examples.getStateName", xmlrpclib.dumps((5,))))

print 'Response from http://betty.userland.com/'
c.perform()
c.cleanup()



# $Id: test_post.py,v 1.4 2002/04/12 09:24:17 kjetilja Exp $

import urllib
import pycurl

# simple
pf = {'field1': 'value1'}

# multiple fields
pf = {'field1':'value1', 'field2':'value2 with blanks', 'field3':'value3'}

# multiple fields with & in field
pf = {'field1':'value1', 'field2':'value2 with blanks and & chars',
      'field3':'value3'}

c = pycurl.init()
c.setopt(pycurl.URL, 'http://pycurl.sourceforge.net/tests/testpostvars.php')
c.setopt(pycurl.POST, 1)
c.setopt(pycurl.POSTFIELDS, urllib.urlencode(pf))
c.perform()
c.cleanup()
